task

package
v2.0.0-alpha.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 28, 2026 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CronParse

func CronParse(spec string) (cron.Schedule, error)

cronParse supports auto-detection of 5 or 6 field Cron expressions

func Kill

func Kill() error

func OnStartupAggregate

func OnStartupAggregate(app *inapi.AppReplicaInstance) (string, string)

OnStartupAggregate reports the aggregate state of OnStartup tasks for stage reporting. Returns one of inapi.AppStageState* (success/running/ failed) and a short summary message. With no OnStartup tasks the result is success (nothing to run).

func ReapOrphans

func ReapOrphans()

ReapOrphans reaps any zombie child processes that were not tracked by execStatuses. This is necessary when inagent runs as PID 1, where all orphaned processes in the container are re-parented to PID 1 and must be explicitly reaped.

func Run

func Run(app *inapi.AppReplicaInstance) error

Types

This section is empty.

Jump to