Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func OnStartupAggregate ¶
func OnStartupAggregate(app *inapi.AppReplicaInstance) (string, string)
OnStartupAggregate reports the aggregate state of OnStartup tasks for stage reporting. Returns one of inapi.AppStageState* (success/running/ failed) and a short summary message. With no OnStartup tasks the result is success (nothing to run).
func ReapOrphans ¶
func ReapOrphans()
ReapOrphans reaps any zombie child processes that were not tracked by execStatuses. This is necessary when inagent runs as PID 1, where all orphaned processes in the container are re-parented to PID 1 and must be explicitly reaped.
func Run ¶
func Run(app *inapi.AppReplicaInstance) error
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.